@@ -23,10 +23,10 @@ copyright = '2020-2022, The Firebird Project'
 author = 'Pavel Císař'
 
 # The short X.Y version
-version = '1.4.1'
+version = '1.4.2'
 
 # The full version, including alpha/beta/rc tags
-release = '1.4.1'
+release = '1.4.2'
 
 
 # -- General configuration ---------------------------------------------------
@@ -35,12 +35,14 @@ release = '1.4.1'
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
+    'sphinx.ext.autodoc',
     'sphinx.ext.napoleon',
-    'sphinx_autodoc_typehints',
+    'sphinx.ext.viewcode',
+    'sphinx.ext.autosectionlabel',
+    #'sphinx_autodoc_typehints',
     'sphinx.ext.todo',
-    'sphinx.ext.coverage',
+    #'sphinx.ext.coverage',
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -61,6 +63,8 @@ default_role = 'py:obj'
 
 # -- Options for HTML output -------------------------------------------------
 
+html_favicon = '_static/fb-favicon.png'
+
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
@@ -158,6 +162,8 @@ html_theme_options = {
 
 # -- Extension configuration -------------------------------------------------
 
+autosectionlabel_prefix_document = True
+
 # Autodoc options
 # ---------------
 autodoc_default_options = {
@@ -170,17 +176,33 @@ autodoc_default_options = {
     'no-inherited-members': True,
 }
 set_type_checking_flag = True
-#always_document_param_types = True
+autodoc_class_signature = 'mixed'
+always_document_param_types = True
+autodoc_typehints = 'both' # default 'signature'
+autodoc_typehints_format = 'short'
+autodoc_typehints_description_target = 'all'
+
+autodoc_type_aliases = {'Item': '~firebird.base.collections.Item',
+                        'TypeSpec': '~firebird.base.collections.TypeSpec',
+                        'ItemExpr': '~firebird.base.collections.ItemExpr',
+                        'FilterExpr': '~firebird.base.collections.FilterExpr',
+                        'CheckExpr': '~firebird.base.collections.CheckExpr',
+                        }
 
 # Napoleon options
 # ----------------
 napoleon_include_init_with_doc = True
 napoleon_include_private_with_doc = True
 napoleon_include_special_with_doc = True
-napoleon_use_admonition_for_examples = True
+napoleon_use_admonition_for_examples = False
 napoleon_use_admonition_for_notes = True
 napoleon_use_admonition_for_references = True
-#napoleon_use_ivar = True
+napoleon_use_ivar = False
+napoleon_use_rtype = True
+napoleon_use_param = True
+napoleon_use_keyword = True
+napoleon_attr_annotations = True
+napoleon_preprocess_types = True
 
 # -- Options for intersphinx extension ---------------------------------------
 
