@@ -28,7 +28,7 @@ from __future__ import annotations
 from typing import Protocol, List, cast
 import unittest
 from enum import Enum, auto
-from firebird.base.hooks import hooks, HookFlag
+from firebird.base.hooks import hook_manager, HookFlag
 from firebird.base.types import ANY
 
 class MyEvents(Enum):
@@ -45,13 +45,13 @@ class MyHookable:
         self.owner = owner
         self.name: str = name
         if register:
-            hooks.register_name(self, name)
+            hook_manager.register_name(self, name)
         subj = self
         if use_class:
             subj = MyHookable
         elif use_name:
             subj = name
-        for hook in hooks.get_callbacks(MyEvents.CREATE, subj):
+        for hook in hook_manager.get_callbacks(MyEvents.CREATE, subj):
             try:
                 hook(self, MyEvents.CREATE)
             except Exception as e:
@@ -60,7 +60,7 @@ class MyHookable:
                 self.owner.print(f"{self.name}.CREATE hook call outcome: OK")
     def action(self):
         self.owner.print(f"{self.name}.ACTION!")
-        for hook in hooks.get_callbacks(MyEvents.ACTION, self):
+        for hook in hook_manager.get_callbacks(MyEvents.ACTION, self):
             try:
                 hook(self, MyEvents.ACTION)
             except Exception as e:
@@ -71,7 +71,7 @@ class MyHookable:
 class MySuperHookable(MyHookable):
     def super_action(self):
         self.owner.print(f"{self.name}.SUPER-ACTION!")
-        for hook in hooks.get_callbacks('super-action', self):
+        for hook in hook_manager.get_callbacks('super-action', self):
             try:
                 hook(self, 'super-action')
             except Exception as e:
@@ -125,42 +125,42 @@ class TestHooks(unittest.TestCase):
         self.output: List = []
     def setUp(self) -> None:
         self.output.clear()
-        hooks.reset()
+        hook_manager.reset()
     def tearDown(self):
         pass
     def print(self, msg: str) -> None:
         self.output.append(msg)
     def test_aaa_hooks(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
-        self.assertTupleEqual(tuple(hooks.hookables.keys()), (MyHookable, ))
-        self.assertSetEqual(hooks.hookables[MyHookable],
+        hook_manager.register_class(MyHookable, MyEvents)
+        self.assertTupleEqual(tuple(hook_manager.hookables.keys()), (MyHookable, ))
+        self.assertSetEqual(hook_manager.hookables[MyHookable],
                             set(x for x in cast(Enum, MyEvents).__members__.values()))
         # Optimizations
-        self.assertNotIn(HookFlag.CLASS, hooks.flags)
-        self.assertNotIn(HookFlag.INSTANCE, hooks.flags)
-        self.assertNotIn(HookFlag.ANY_EVENT, hooks.flags)
-        self.assertNotIn(HookFlag.NAME, hooks.flags)
+        self.assertNotIn(HookFlag.CLASS, hook_manager.flags)
+        self.assertNotIn(HookFlag.INSTANCE, hook_manager.flags)
+        self.assertNotIn(HookFlag.ANY_EVENT, hook_manager.flags)
+        self.assertNotIn(HookFlag.NAME, hook_manager.flags)
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         hook_N: MyHook = MyHook(self, 'Hook-N')
         #
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
-        self.assertIn(HookFlag.CLASS, hooks.flags)
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
-        hooks.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
-        hooks.add_hook(MyEvents.ACTION, 'Source-A', hook_N.callback)
-        self.assertIn(HookFlag.NAME, hooks.flags)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        self.assertIn(HookFlag.CLASS, hook_manager.flags)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
+        hook_manager.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
+        hook_manager.add_hook(MyEvents.ACTION, 'Source-A', hook_N.callback)
+        self.assertIn(HookFlag.NAME, hook_manager.flags)
         #
         key = (MyEvents.CREATE, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
-        self.assertIn(hook_B.err_callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
+        self.assertIn(hook_B.err_callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_C.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_C.callback, hook_manager.hooks[key].callbacks)
         # Create event sources, emits CREATE
         self.output.clear()
         src_A: MyHookable = MyHookable(self, 'Source-A', register=True)
@@ -177,16 +177,16 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-B event CREATE called by Source-B',
                               'Source-B.CREATE hook call outcome: ERROR (Error in hook)'])
         # Install instance hooks
-        hooks.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
-        self.assertIn(HookFlag.INSTANCE, hooks.flags)
-        hooks.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
+        hook_manager.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
+        self.assertIn(HookFlag.INSTANCE, hook_manager.flags)
+        hook_manager.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
         #
         key = (MyEvents.ACTION, ANY, src_A)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, ANY, src_B)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_B.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_B.callback, hook_manager.hooks[key].callbacks)
         # And action!
         self.output.clear()
         src_A.action()
@@ -208,51 +208,51 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-C event ACTION called by Source-B',
                               'Source-B.ACTION hook call outcome: OK'])
         # Optimizations
-        self.assertIn(HookFlag.CLASS, hooks.flags)
-        self.assertIn(HookFlag.INSTANCE, hooks.flags)
-        self.assertNotIn(HookFlag.ANY_EVENT, hooks.flags)
-        self.assertIn(HookFlag.NAME, hooks.flags)
+        self.assertIn(HookFlag.CLASS, hook_manager.flags)
+        self.assertIn(HookFlag.INSTANCE, hook_manager.flags)
+        self.assertNotIn(HookFlag.ANY_EVENT, hook_manager.flags)
+        self.assertIn(HookFlag.NAME, hook_manager.flags)
         # Remove hooks
-        hooks.remove_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        hook_manager.remove_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
         key = (MyEvents.CREATE, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertNotIn(hook_A.callback, hooks.hooks[key].callbacks)
-        hooks.remove_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
-        self.assertFalse(key in hooks.hooks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertNotIn(hook_A.callback, hook_manager.hooks[key].callbacks)
+        hook_manager.remove_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
+        self.assertFalse(key in hook_manager.hooks)
         #
-        hooks.remove_hook(MyEvents.ACTION, src_A, hook_A.callback)
+        hook_manager.remove_hook(MyEvents.ACTION, src_A, hook_A.callback)
         key = (MyEvents.ACTION, ANY, src_A)
-        self.assertFalse(key in hooks.hooks)
+        self.assertFalse(key in hook_manager.hooks)
         #
-        hooks.remove_all_hooks()
-        self.assertEqual(len(hooks.hooks), 0)
+        hook_manager.remove_all_hooks()
+        self.assertEqual(len(hook_manager.hooks), 0)
         #
-        hooks.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
-        hooks.reset()
-        self.assertEqual(len(hooks.hookables), 0)
-        self.assertEqual(len(hooks.hooks), 0)
+        hook_manager.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
+        hook_manager.reset()
+        self.assertEqual(len(hook_manager.hookables), 0)
+        self.assertEqual(len(hook_manager.hooks), 0)
     def test_inherited_hookable(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
-        self.assertTupleEqual(tuple(hooks.hookables.keys()), (MyHookable, ))
-        self.assertSetEqual(hooks.hookables[MyHookable],
+        hook_manager.register_class(MyHookable, MyEvents)
+        self.assertTupleEqual(tuple(hook_manager.hookables.keys()), (MyHookable, ))
+        self.assertSetEqual(hook_manager.hookables[MyHookable],
                             set(x for x in cast(Enum, MyEvents).__members__.values()))
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         #
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
-        hooks.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_B.err_callback)
+        hook_manager.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
         #
         key = (MyEvents.CREATE, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
-        self.assertIn(hook_B.err_callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
+        self.assertIn(hook_B.err_callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_C.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_C.callback, hook_manager.hooks[key].callbacks)
         # Create event sources, emits CREATE
         self.output.clear()
         src_A: MySuperHookable = MySuperHookable(self, 'SuperSource-A')
@@ -269,15 +269,15 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-B event CREATE called by SuperSource-B',
                               'SuperSource-B.CREATE hook call outcome: ERROR (Error in hook)'])
         # Install instance hooks
-        hooks.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
-        hooks.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
+        hook_manager.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
+        hook_manager.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
         #
         key = (MyEvents.ACTION, ANY, src_A)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, ANY, src_B)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_B.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_B.callback, hook_manager.hooks[key].callbacks)
         # And action!
         self.output.clear()
         src_A.action()
@@ -298,32 +298,32 @@ class TestHooks(unittest.TestCase):
                               'SuperSource-B.ACTION hook call outcome: OK'])
     def test_inheritance(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
-        hooks.register_class(MySuperHookable, ('super-action', ))
-        self.assertTupleEqual(tuple(hooks.hookables.keys()), (MyHookable, MySuperHookable))
-        self.assertSetEqual(hooks.hookables[MyHookable],
+        hook_manager.register_class(MyHookable, MyEvents)
+        hook_manager.register_class(MySuperHookable, ('super-action', ))
+        self.assertTupleEqual(tuple(hook_manager.hookables.keys()), (MyHookable, MySuperHookable))
+        self.assertSetEqual(hook_manager.hookables[MyHookable],
                             set(x for x in cast(Enum, MyEvents).__members__.values()))
-        self.assertTupleEqual(hooks.hookables[MySuperHookable], ('super-action', ))
+        self.assertTupleEqual(hook_manager.hookables[MySuperHookable], ('super-action', ))
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         hook_S: MyHook = MyHook(self, 'Hook-S')
         #
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
-        hooks.add_hook(MyEvents.CREATE, MySuperHookable, hook_B.err_callback)
-        hooks.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
-        hooks.add_hook('super-action', MySuperHookable, hook_S.callback)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        hook_manager.add_hook(MyEvents.CREATE, MySuperHookable, hook_B.err_callback)
+        hook_manager.add_hook(MyEvents.ACTION, MyHookable, hook_C.callback)
+        hook_manager.add_hook('super-action', MySuperHookable, hook_S.callback)
         #
         key = (MyEvents.CREATE, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.CREATE, MySuperHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_B.err_callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_B.err_callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, MyHookable, ANY)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_C.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_C.callback, hook_manager.hooks[key].callbacks)
         # Create event sources, emits CREATE
         self.output.clear()
         src_A: MySuperHookable = MySuperHookable(self, 'SuperSource-A')
@@ -340,15 +340,15 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-B event CREATE called by SuperSource-B',
                               'SuperSource-B.CREATE hook call outcome: ERROR (Error in hook)'])
         # Install instance hooks
-        hooks.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
-        hooks.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
+        hook_manager.add_hook(MyEvents.ACTION, src_A, hook_A.callback)
+        hook_manager.add_hook(MyEvents.ACTION, src_B, hook_B.callback)
         #
         key = (MyEvents.ACTION, ANY, src_A)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_A.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_A.callback, hook_manager.hooks[key].callbacks)
         key = (MyEvents.ACTION, ANY, src_B)
-        self.assertTrue(key in hooks.hooks)
-        self.assertIn(hook_B.callback, hooks.hooks[key].callbacks)
+        self.assertTrue(key in hook_manager.hooks)
+        self.assertIn(hook_B.callback, hook_manager.hooks[key].callbacks)
         # And action!
         self.output.clear()
         src_A.action()
@@ -376,48 +376,48 @@ class TestHooks(unittest.TestCase):
                               'SuperSource-B.SUPER-ACTION hook call outcome: OK'])
     def test_bad_hooks(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
-        hooks.register_class(MySuperHookable, ('super-action', ))
+        hook_manager.register_class(MyHookable, MyEvents)
+        hook_manager.register_class(MySuperHookable, ('super-action', ))
         src_A: MyHookable = MyHookable(self, 'Source-A')
         src_B: MySuperHookable = MySuperHookable(self, 'SuperSource-B')
         # Install hooks
         bad_hook: MyHook = MyHook(self, 'BAD-Hook')
         # Wrong hookables
         with self.assertRaises(TypeError) as cm:
-            hooks.add_hook(MyEvents.CREATE, ANY, bad_hook.callback) # hook object
+            hook_manager.add_hook(MyEvents.CREATE, ANY, bad_hook.callback) # hook object
         self.assertEqual(cm.exception.args, ("Subject must be hookable class or instance, or name",))
         with self.assertRaises(TypeError) as cm:
-            hooks.add_hook(MyEvents.CREATE, Enum, bad_hook.callback) # hook class
+            hook_manager.add_hook(MyEvents.CREATE, Enum, bad_hook.callback) # hook class
         self.assertEqual(cm.exception.args, ('The type is not registered as hookable',))
-        self.assertDictEqual(hooks.hooks._reg, {})
+        self.assertDictEqual(hook_manager.hooks._reg, {})
         # Wrong events
         with self.assertRaises(ValueError) as cm:
-            hooks.add_hook('BAD EVENT', MyHookable, bad_hook.callback)
+            hook_manager.add_hook('BAD EVENT', MyHookable, bad_hook.callback)
         self.assertEqual(cm.exception.args, ("Event 'BAD EVENT' is not supported by 'MyHookable'",))
         with self.assertRaises(ValueError) as cm:
-            hooks.add_hook('BAD EVENT', MySuperHookable, bad_hook.callback)
+            hook_manager.add_hook('BAD EVENT', MySuperHookable, bad_hook.callback)
         self.assertEqual(cm.exception.args, ("Event 'BAD EVENT' is not supported by 'MySuperHookable'",))
         #
         with self.assertRaises(ValueError) as cm:
-            hooks.add_hook('BAD EVENT', src_A, bad_hook.callback)
+            hook_manager.add_hook('BAD EVENT', src_A, bad_hook.callback)
         self.assertEqual(cm.exception.args, ("Event 'BAD EVENT' is not supported by 'MyHookable'",))
         with self.assertRaises(ValueError) as cm:
-            hooks.add_hook('BAD EVENT', src_B, bad_hook.callback)
+            hook_manager.add_hook('BAD EVENT', src_B, bad_hook.callback)
         self.assertEqual(cm.exception.args, ("Event 'BAD EVENT' is not supported by 'MySuperHookable'",))
         # Bad hookable instances
         with self.assertRaises(TypeError) as cm:
-            hooks.register_name(self, 'BAD_CLASS')
+            hook_manager.register_name(self, 'BAD_CLASS')
         self.assertEqual(cm.exception.args, ("The instance is not of hookable type",))
     def test_any_event(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
+        hook_manager.register_class(MyHookable, MyEvents)
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         hook_D: MyHook = MyHook(self, 'Hook-D')
-        hooks.add_hook(ANY, MyHookable, hook_A.callback)
-        hooks.add_hook(ANY, MyHookable, hook_B.err_callback)
+        hook_manager.add_hook(ANY, MyHookable, hook_A.callback)
+        hook_manager.add_hook(ANY, MyHookable, hook_B.err_callback)
         # Create event sources, emits CREATE
         self.output.clear()
         src_A: MyHookable = MyHookable(self, 'Source-A', register=True)
@@ -427,8 +427,8 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-B event CREATE called by Source-A',
                               'Source-A.CREATE hook call outcome: ERROR (Error in hook)'])
         # Install instance hooks
-        hooks.add_hook(ANY, src_A, hook_C.callback)
-        hooks.add_hook(ANY, 'Source-A', hook_D.callback)
+        hook_manager.add_hook(ANY, src_A, hook_C.callback)
+        hook_manager.add_hook(ANY, 'Source-A', hook_D.callback)
         # And action!
         self.output.clear()
         src_A.action()
@@ -443,22 +443,22 @@ class TestHooks(unittest.TestCase):
                               'Hook Hook-B event ACTION called by Source-A',
                               'Source-A.ACTION hook call outcome: ERROR (Error in hook)'])
         # Optimizations
-        self.assertIn(HookFlag.CLASS, hooks.flags)
-        self.assertIn(HookFlag.INSTANCE, hooks.flags)
-        self.assertIn(HookFlag.ANY_EVENT, hooks.flags)
-        self.assertIn(HookFlag.NAME, hooks.flags)
+        self.assertIn(HookFlag.CLASS, hook_manager.flags)
+        self.assertIn(HookFlag.INSTANCE, hook_manager.flags)
+        self.assertIn(HookFlag.ANY_EVENT, hook_manager.flags)
+        self.assertIn(HookFlag.NAME, hook_manager.flags)
     def test_class_hooks(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
+        hook_manager.register_class(MyHookable, MyEvents)
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         hook_D: MyHook = MyHook(self, 'Hook-D')
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
-        hooks.add_hook(ANY, MyHookable, hook_B.err_callback)
-        hooks.add_hook(MyEvents.CREATE, 'Source-A', hook_C.callback)
-        hooks.add_hook(ANY, 'Source-A', hook_D.callback)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        hook_manager.add_hook(ANY, MyHookable, hook_B.err_callback)
+        hook_manager.add_hook(MyEvents.CREATE, 'Source-A', hook_C.callback)
+        hook_manager.add_hook(ANY, 'Source-A', hook_D.callback)
         # Create event sources, emits CREATE
         self.output.clear()
         MyHookable(self, 'Source-A', use_class=True)
@@ -469,16 +469,16 @@ class TestHooks(unittest.TestCase):
                               'Source-A.CREATE hook call outcome: ERROR (Error in hook)'])
     def test_name_hooks(self):
         # register hookables
-        hooks.register_class(MyHookable, MyEvents)
+        hook_manager.register_class(MyHookable, MyEvents)
         # Install hooks
         hook_A: MyHook = MyHook(self, 'Hook-A')
         hook_B: MyHook = MyHook(self, 'Hook-B')
         hook_C: MyHook = MyHook(self, 'Hook-C')
         hook_D: MyHook = MyHook(self, 'Hook-D')
-        hooks.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
-        hooks.add_hook(ANY, MyHookable, hook_B.err_callback)
-        hooks.add_hook(MyEvents.CREATE, 'Source-A', hook_C.callback)
-        hooks.add_hook(ANY, 'Source-A', hook_D.err_callback)
+        hook_manager.add_hook(MyEvents.CREATE, MyHookable, hook_A.callback)
+        hook_manager.add_hook(ANY, MyHookable, hook_B.err_callback)
+        hook_manager.add_hook(MyEvents.CREATE, 'Source-A', hook_C.callback)
+        hook_manager.add_hook(ANY, 'Source-A', hook_D.err_callback)
         # Create event sources, emits CREATE
         self.output.clear()
         MyHookable(self, 'Source-A', use_name=True)
